#!/usr/bin/env python3
#import string
import sys
import math

################# スカラー値で表現された特徴量同士のマッチングを行う関数 #################
# feature1: 匿名加工前の特徴量(顧客ID毎), m1_size: 顧客IDの総数
# feature2: 匿名加工後の特徴量(仮ID毎), m2_size: 仮IDの総数
# line_kaID: (行番号⇒仮ID), koID_line: (顧客ID⇒行番号)
def ScalarFeatureMatching(feature1, m1_size, feature2, m2_size, line_kaID, koID_line):
    # 特徴量feature1の小さい順に顧客IDをソート(顧客ID,特徴量) --> m1_ID, m1_feature
    m1_ID = []
    m1_feature = []
    for k, v in sorted(feature1.items(), key=lambda x:x[1]):
        m1_ID.append(k)
        m1_feature.append(v)

#    for i in range(m1_size):
#        print(i, m1_ID[i], m1_feature[i])

    # 特徴量feature2の小さい順に顧客IDをソート(顧客ID,特徴量) --> m2_ID, m2_feature
    m2_ID = []
    m2_feature = []
    for k, v in sorted(feature2.items(), key=lambda x:x[1]):
        m2_ID.append(k)
        m2_feature.append(v)

#    for i in range(m2_size):
#        print(i, m2_ID[i], m2_feature[i])

    # 各仮IDに対して，特徴量が最も近い顧客IDを対応付ける((仮ID⇒顧客ID)) --> kaID_koID
    i = 0
    kaID_koID = {}
    for j in range(m2_size):
        while i < m1_size and m2_feature[j] > m1_feature[i]:
            i += 1
            
        if i == 0:
            kaID_koID[m2_ID[j]] = m1_ID[i]
        elif i == m1_size:
            kaID_koID[m2_ID[j]] = m1_ID[i - 1]
        elif (math.fabs(m2_feature[j] - m1_feature[i - 1]) < math.fabs(m2_feature[j] - m1_feature[i])):
            kaID_koID[m2_ID[j]] = m1_ID[i - 1]
        else:
            kaID_koID[m2_ID[j]] = m1_ID[i]

    #行番号Pの推定値 --> p
    p = []
    for i in range(m2_size):
        j = line_kaID[i]
        k = kaID_koID[j]
        l = koID_line[k]
        p.append(l+1)

    #行番号Pの推定値を返す
    return p
###############################################################################

############################## 入力データの読み込み ##############################
# マスターM1の読み込み(レコード数,生年月日,(顧客ID⇒行番号)) --> m1_size, birth1, koID_line
# 顧客毎のデータ(平均購入時刻,総価格,レコード数)の初期化 --> time1, price1, rec1
m1_size = int(sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n'))
birth1 = {}
koID_line = {}
time1 = {}
price1 = {}
rec1 = {}
for item in range(m1_size):
    # 1行ずつ読み込み
    item_string = (sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n')).strip()
    item_list = item_string.split(",")
    item_id = item_list[0]
    item_birth = item_list[2]
    # 生年月日 --> birth1
    birth_list = item_birth.split("/")
    birthday = int(birth_list[0])*12*31+int(birth_list[1])*31+int(birth_list[2])
    birth1[item_id] = birthday
    # (顧客ID⇒行番号) --> koID_line
    koID_line[item_id] = item
    # 初期化
    time1[item_id] = 0
    price1[item_id] = 0
    rec1[item_id] = 0

# トランザクションT1の読み込み(レコード数,顧客毎のデータ(平均購入時刻,総価格,レコード数))
# --> t1_size, time1, price1, rec1
t1_size = int(sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n'))
for item in range(t1_size):
    # 1行ずつ読み込み
    item_string = (sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n')).strip()
    item_list = item_string.split(",")
    item_id = item_list[0]
    item_time = item_list[2]
    item_time2 = item_list[3]
    # 平均購入時刻 --> time1
    ymd_list = item_time.split("/")
    hm_list = item_time2.split(":")
    item_time = int(ymd_list[0])*12*31+int(ymd_list[1])*31+int(ymd_list[2])
    item_time *= (24*60)
    item_time += int(hm_list[0])*60+int(hm_list[1])
    time1[item_id] += item_time
    # 総価格 --> price1
    item_price = item_list[5]
    item_num = item_list[6]
    price1[item_id] += float(item_price) * int(item_num)
    # レコード数 --> rec1
    rec1[item_id] += 1

# 購入時刻の総和をレコード数で割ることで，平均購入時刻を求める --> time1
for k, v in sorted(rec1.items(), key=lambda x:x[0]):
    time1[k] /= rec1[k]

# 匿名加工マスターM2の読み込み(レコード数,生年月日,(行番号⇒仮ID)) --> m2_size, birth2, line_kaID
# 顧客毎のデータ(平均購入時刻,総価格,レコード数)の初期化 --> time2, price2, rec2
m2_size = int(sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n'))
birth2 = {}
line_kaID = []
time2 = {}
price2 = {}
rec2 = {}
for item in range(m2_size):
    # 1行ずつ読み込み
    item_string = (sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n')).strip()
    item_list = item_string.split(",")
    item_id = item_list[0]
    item_birth = item_list[2]
    # 生年月日 --> birth2
    birth_list = item_birth.split("/")
    birthday = int(birth_list[0])*12*31+int(birth_list[1])*31+int(birth_list[2])
    birth2[item_id] = birthday
    # (行番号⇒仮ID) --> line_kaID
    line_kaID.append(item_id)
    # 初期化
    time2[item_id] = 0
    price2[item_id] = 0
    rec2[item_id] = 0

# 匿名加工トランザクションT2の読み込み(レコード数,顧客毎のデータ(平均購入時刻,総価格,レコード数))
# --> t2_size, time2, price2, rec2
t2_size = int(sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n'))
for item in range(t2_size):
    # 1行ずつ読み込み
    item_string = (sys.stdin.readline().replace(('¥r'or'¥n'),'¥r¥n')).strip()
    item_list = item_string.split(",")
    item_id = item_list[0]
    item_time = item_list[2]
    item_time2 = item_list[3]
    # 平均購入時刻 --> time2
    ymd_list = item_time.split("/")
    hm_list = item_time2.split(":")
    item_time = int(ymd_list[0])*12*31+int(ymd_list[1])*31+int(ymd_list[2])
    item_time *= (24*60)
    item_time += int(hm_list[0])*60+int(hm_list[1])
    time2[item_id] += item_time
    # 総価格 --> price2
    item_price = item_list[5]
    item_num = item_list[6]
    price2[item_id] += float(item_price) * int(item_num)
    # レコード数 --> rec2
    rec2[item_id] += 1

# 購入時刻の総和をレコード数で割ることで，平均購入時刻を求める --> time2
for k, v in sorted(rec2.items(), key=lambda x:x[0]):
    time2[k] /= rec2[k]
###############################################################################

##################### スカラー値で表現された特徴量同士のマッチング #####################
# 生年月日
p1 = ScalarFeatureMatching(birth1, m1_size, birth2, m2_size, line_kaID, koID_line)
# 平均購入時刻
p2 = ScalarFeatureMatching(time1, m1_size, time2, m2_size, line_kaID, koID_line)
# 総価格
p3 = ScalarFeatureMatching(price1, m1_size, price2, m2_size, line_kaID, koID_line)
###############################################################################

################################## 多数決判定 ##################################
#行数出力
print(m2_size)
for i in range(m2_size):
    if p1[i] == p2[i]:
        print(p1[i])
    elif p2[i] == p3[i]:
        print(p2[i])
    elif p3[i] == p1[i]:
        print(p3[i])
    # 全て異なる場合
    else:
        print(p2[i])

###############################################################################
